==> coupon-facade-2.0.0-20200227.124315-55-sources.jar: com/bizvane/couponfacade/models/vo/CouponAllUseRequestVO.java <==
package com.bizvane.couponfacade.models.vo;

import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;
import java.math.BigDecimal;

/**
 * Created by yunjie.tian on 2018/11/7.
 */
public class CouponAllUseRequestVO implements Serializable{

    @ApiModelProperty(value = "券号", name = "couponCode", required = false,example = "")
    private String couponCode;

    @ApiModelProperty(value = "品牌id", name = "brandId", required = false,example = "")
    private Long brandId;

    @ApiModelProperty(value = "企业id", name = "sysCompanyId", required = false,example = "")
    private Long sysCompanyId;

    @ApiModelProperty(value = "订单号", name = "useBusinessCode", required = false,example = "")
    private String useBusinessCode;

    @ApiModelProperty(value = "核销金额", name = "profitMoney", required = false,example = "")
    private BigDecimal profitMoney;

    @ApiModelProperty(value = "优惠金额", name = "discountMoney", required = false,example = "")
    private BigDecimal discountMoney;

    @io.swagger.annotations.ApiModelProperty(value = "店铺id", name = "useStoreId", required = false,example = "")
    private Long useStoreId;

    @ApiModelProperty(value = "核销来源", name = "useFrom", required = false,example = "")
    private Byte useFrom;

    @io.swagger.annotations.ApiModelProperty(value = "员工编号", name = "staffCode", required = false,example = "")
    private String staffCode;
    
    @io.swagger.annotations.ApiModelProperty(value = "核销门店code", name = "核销门店code", required = false,example = "")
    private String verifyedStoreCode;
    
    @io.swagger.annotations.ApiModelProperty(value = "核销人(导购code)", name = "导购code", required = false,example = "")
    private String verifyedUser;

    @io.swagger.annotations.ApiModelProperty(value = "核销会员的cde", name = "useMemberCode", required = false,example = "")
    private String useMemberCode;

    public String getVerifyedUser() {
		return verifyedUser;
	}

	public void setVerifyedUser(String verifyedUser) {
		this.verifyedUser = verifyedUser;
	}

	public String getVerifyedStoreCode() {
  		return verifyedStoreCode;
  	}

  	public void setVerifyedStoreCode(String verifyedStoreCode) {
  		this.verifyedStoreCode = verifyedStoreCode;
  	}

    public String getStaffCode() {
        return staffCode;
    }

    public void setStaffCode(String staffCode) {
        this.staffCode = staffCode;
    }


    public Long getUseStoreId() {
        return useStoreId;
    }

    public void setUseStoreId(Long useStoreId) {
        this.useStoreId = useStoreId;
    }

    public Byte getUseFrom() {
        return useFrom;
    }

    public void setUseFrom(Byte useFrom) {
        this.useFrom = useFrom;
    }

    public String getCouponCode() {
        return couponCode;
    }

    public void setCouponCode(String couponCode) {
        this.couponCode = couponCode;
    }

    public String getUseBusinessCode() {
        return useBusinessCode;
    }

    public void setUseBusinessCode(String useBusinessCode) {
        this.useBusinessCode = useBusinessCode;
    }

    public Long getBrandId() {
        return brandId;
    }

    public void setBrandId(Long brandId) {
        this.brandId = brandId;
    }

    public Long getSysCompanyId() {
        return sysCompanyId;
    }

    public void setSysCompanyId(Long sysCompanyId) {
        this.sysCompanyId = sysCompanyId;
    }

    public BigDecimal getProfitMoney() {
        return profitMoney;
    }

    public void setProfitMoney(BigDecimal profitMoney) {
        this.profitMoney = profitMoney;
    }

    public BigDecimal getDiscountMoney() {
        return discountMoney;
    }

    public void setDiscountMoney(BigDecimal discountMoney) {
        this.discountMoney = discountMoney;
    }

    public String getUseMemberCode() {
        return useMemberCode;
    }

    public void setUseMemberCode(String useMemberCode) {
        this.useMemberCode = useMemberCode;
    }
}

==> coupon-facade-2.0.0-20200323.123007-72-sources.jar: com/bizvane/couponfacade/models/vo/CouponAllUseRequestVO.java <==
package com.bizvane.couponfacade.models.vo;

import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;
import java.math.BigDecimal;

/**
 * Created by yunjie.tian on 2018/11/7.
 */
public class CouponAllUseRequestVO implements Serializable{

    @ApiModelProperty(value = "券号", name = "couponCode", required = false,example = "")
    private String couponCode;

    @ApiModelProperty(value = "品牌id", name = "brandId", required = false,example = "")
    private Long brandId;

    @ApiModelProperty(value = "企业id", name = "sysCompanyId", required = false,example = "")
    private Long sysCompanyId;

    @ApiModelProperty(value = "订单号", name = "useBusinessCode", required = false,example = "")
    private String useBusinessCode;

    @ApiModelProperty(value = "核销金额", name = "profitMoney", required = false,example = "")
    private BigDecimal profitMoney;

    @ApiModelProperty(value = "优惠金额", name = "discountMoney", required = false,example = "")
    private BigDecimal discountMoney;

    @io.swagger.annotations.ApiModelProperty(value = "店铺id", name = "useStoreId", required = false,example = "")
    private Long useStoreId;

    @ApiModelProperty(value = "核销来源", name = "useFrom", required = false,example = "")
    private Byte useFrom;

    @io.swagger.annotations.ApiModelProperty(value = "员工编号", name = "staffCode", required = false,example = "")
    private String staffCode;
    
    @io.swagger.annotations.ApiModelProperty(value = "核销门店code", name = "核销门店code", required = false,example = "")
    private String verifyedStoreCode;
    
    @io.swagger.annotations.ApiModelProperty(value = "核销人(导购code)", name = "导购code", required = false,example = "")
    private String verifyedUser;

    @io.swagger.annotations.ApiModelProperty(value = "核销会员的cde", name = "useMemberCode", required = false,example = "")
    private String useMemberCode;

    private String offlinePrdCode;

    public String getVerifyedUser() {
		return verifyedUser;
	}

	public void setVerifyedUser(String verifyedUser) {
		this.verifyedUser = verifyedUser;
	}

	public String getVerifyedStoreCode() {
  		return verifyedStoreCode;
  	}

  	public void setVerifyedStoreCode(String verifyedStoreCode) {
  		this.verifyedStoreCode = verifyedStoreCode;
  	}

    public String getStaffCode() {
        return staffCode;
    }

    public void setStaffCode(String staffCode) {
        this.staffCode = staffCode;
    }


    public Long getUseStoreId() {
        return useStoreId;
    }

    public void setUseStoreId(Long useStoreId) {
        this.useStoreId = useStoreId;
    }

    public Byte getUseFrom() {
        return useFrom;
    }

    public void setUseFrom(Byte useFrom) {
        this.useFrom = useFrom;
    }

    public String getCouponCode() {
        return couponCode;
    }

    public void setCouponCode(String couponCode) {
        this.couponCode = couponCode;
    }

    public String getUseBusinessCode() {
        return useBusinessCode;
    }

    public void setUseBusinessCode(String useBusinessCode) {
        this.useBusinessCode = useBusinessCode;
    }

    public Long getBrandId() {
        return brandId;
    }

    public void setBrandId(Long brandId) {
        this.brandId = brandId;
    }

    public Long getSysCompanyId() {
        return sysCompanyId;
    }

    public void setSysCompanyId(Long sysCompanyId) {
        this.sysCompanyId = sysCompanyId;
    }

    public BigDecimal getProfitMoney() {
        return profitMoney;
    }

    public void setProfitMoney(BigDecimal profitMoney) {
        this.profitMoney = profitMoney;
    }

    public BigDecimal getDiscountMoney() {
        return discountMoney;
    }

    public void setDiscountMoney(BigDecimal discountMoney) {
        this.discountMoney = discountMoney;
    }

    public String getUseMemberCode() {
        return useMemberCode;
    }

    public void setUseMemberCode(String useMemberCode) {
        this.useMemberCode = useMemberCode;
    }

    public String getOfflinePrdCode() {
        return offlinePrdCode;
    }

    public void setOfflinePrdCode(String offlinePrdCode) {
        this.offlinePrdCode = offlinePrdCode;
    }
}
